===============================
Contributing to mixpanel-celery
===============================

Contribution of all types is very welcome via github pull requests.
Have something you think might possibly be useful to other folks?
Please send a pull request!

We'll definitely add you to the ``AUTHORS`` file,
unless you request otherwise,
so if you'd like to use contact info other than your github profile,
let us know in your pull request.

Contribution Tips
=================

Some general tips for making your pull request easy to accept:

1. Detailed Description
-----------------------

Provide a detailed description in your pull request
so we know exactly what you're trying to accomplish.
That way,
if it's 90% there,
it will be obvious how we can get it that extra 10%.

2. Follow PEP8
--------------

Code should be pep8 compatible. We recommend using `flake8`_.

3. Include Tests
----------------

Bug fixes and features should come with additional tests
and all existing tests should be passing.
If you're not sure how to test your change,
feel free to submit it anyway with a comment indicating so.

4. Documentation
----------------

Any new features should include documentation for those features.

.. _`flake8`: https://pypi.python.org/pypi/flake8


